@@ -11,6 +11,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <stdarg.h>
+#include <string.h>
 #define ERR error("Error at line %d, file %s, compiled %s %s\n", __LINE__,__FILE__,__DATE__,__TIME__);
 #define ln() putchar('\n')
 #define MAX_SYSTEM_CMD 255
@@ -18,5 +19,6 @@ int system_printf(char*, ...);
 int debug(char*, ...);
 int fatal(char*, ...);
 int error(char*, ...);
+void downcase(char*);
 void print_results(char***, int, int);
 #endif
