@@ -1,4 +1,3 @@
-
 /* Written by Morgoth DBMA, morgothdbma@o2.pl
  This is part of PgXexplorer software, Open Source
  on BSD licence, Libraries(interaces) used:
@@ -8,7 +7,6 @@
  Currently only one author: MOrgoth DBMA
  FILE: gtkdialogs.c */
 #include "gtkdialogs.h"
-
 static int answer = ANSWER_YES;
 static char tentry[MAX_ENTRY_LENGTH];
 static char*** ptr = NULL;
@@ -21,6 +19,7 @@ void destroy_fs(GtkWidget* w, gpointer d)
  gtk_widget_destroy((GtkWidget*)(d));
 }
 
+
 void cancel_fs(GtkWidget* w, gpointer d)
 {
  gtk_main_quit();
@@ -28,6 +27,7 @@ void cancel_fs(GtkWidget* w, gpointer d)
  strcpy(tentry,"");
 }
 
+
 void ok_fs(GtkWidget* w, gpointer d)
 {
  strcpy(tentry,gtk_file_selection_get_filename((GTK_FILE_SELECTION(d))));
@@ -35,6 +35,7 @@ void ok_fs(GtkWidget* w, gpointer d)
  gtk_widget_destroy((GtkWidget*)(d));
 }
 
+
 gint delete_event_proc()
 {
  answer = ANSWER_NO;
@@ -43,16 +44,18 @@ gint delete_event_proc()
  return FALSE;
 }
 
-gint delete_combos_proc()
+
+gint delete_combos_proc(GtkWidget* w, gpointer d)
 {
  answer = ANSWER_NO;
  strcpy(tentry, "");
  gtk_main_quit();
  free_p3c(&ptr, row, col);
  ptr=NULL;
- return FALSE;
+ return TRUE;
 }
 
+
 void ok_proc(GtkWidget* w, gpointer d)
 {
  gtk_main_quit();
@@ -68,11 +71,13 @@ void ok_combo_proc(GtkWidget* w, gpointer cmb)
  ptr=NULL;
 }
 
+
 void entry_changed_proc(GtkWidget* w, gpointer d)
 {
  strcpy(tentry,gtk_entry_get_text(GTK_ENTRY(w)));
 }
 
+
 void entry_proc(GtkWidget* w, gpointer d)
 {
  strcpy(tentry,gtk_entry_get_text(GTK_ENTRY(w)));
@@ -80,6 +85,7 @@ void entry_proc(GtkWidget* w, gpointer d)
  gtk_widget_destroy((GtkWidget*)(d));
 }
 
+
 void yes_proc(GtkWidget* w, gpointer d)
 {
  answer = ANSWER_YES;
@@ -87,6 +93,7 @@ void yes_proc(GtkWidget* w, gpointer d)
  gtk_widget_destroy((GtkWidget*)(d));
 }
 
+
 void no_proc(GtkWidget* w, gpointer d)
 {
  answer = ANSWER_NO;
@@ -94,6 +101,7 @@ void no_proc(GtkWidget* w, gpointer d)
  gtk_widget_destroy((GtkWidget*)(d));
 }
 
+
 char* gtk_dialog_getfile_printf(const char* fmt, ...)
 {
  va_list ap;
@@ -104,6 +112,7 @@ char* gtk_dialog_getfile_printf(const char* fmt, ...)
  return gtk_dialog_getfile(msg);
 }
 
+
 char* gtk_dialog_gettext_printf(const char* fmt, ...)
 {
  va_list ap;
@@ -114,27 +123,29 @@ char* gtk_dialog_gettext_printf(const char* fmt, ...)
  return gtk_dialog_gettext(msg);
 }
 
+
 char* gtk_dialog_getfile(const char* question)
 {
  GtkWidget* filew;
  filew = gtk_file_selection_new(question);
  gtk_signal_connect(GTK_OBJECT(filew), "destroy", GTK_SIGNAL_FUNC(destroy_fs), (gpointer)filew);
- gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(filew)->ok_button), 
+ gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(filew)->ok_button),
 		 "clicked", GTK_SIGNAL_FUNC(ok_fs), (gpointer)filew);
- gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(filew)->cancel_button), 
+ gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(filew)->cancel_button),
 		 "clicked", GTK_SIGNAL_FUNC(cancel_fs), (gpointer)filew);
  gtk_widget_show(filew);
  gtk_main();
  return tentry;
 }
 
+
 char* gtk_dialog_gettext(const char* question)
 {
  GtkWidget* dialog, *label, *button, *entry;
  strcpy(tentry, "");
  dialog = gtk_dialog_new();
  gtk_window_set_title(GTK_WINDOW(dialog), "Enter text");
- gtk_widget_set_usize(dialog, 300, 100);
+ gtk_widget_set_usize(dialog, 500, 100);
  gtk_window_set_modal(GTK_WINDOW(dialog), 1);
  label = gtk_label_new(question);
  entry = gtk_entry_new();
@@ -168,6 +179,7 @@ void gtk_dialog_printf(const char* fmt, ...)
  va_end(ap);
 }
 
+
 void gtk_dialog_printf_big_with_title(const char* title, const char* fmt, ...)
 {
  GtkWidget* dialog, *label, *button;
@@ -193,6 +205,7 @@ void gtk_dialog_printf_big_with_title(const char* title, const char* fmt, ...)
  gtk_main();
 }
 
+
 void gtk_dialog_printf_big(const char* fmt, ...)
 {
  GtkWidget* dialog, *label, *button;
@@ -218,6 +231,7 @@ void gtk_dialog_printf_big(const char* fmt, ...)
  gtk_main();
 }
 
+
 void gtk_dialog_printf_with_title(const char* title, const char* fmt, ...)
 {
  GtkWidget* dialog, *label, *button;
@@ -228,7 +242,7 @@ void gtk_dialog_printf_with_title(const char* title, const char* fmt, ...)
  va_end(ap);
  dialog = gtk_dialog_new();
  gtk_window_set_title(GTK_WINDOW(dialog), title);
- gtk_widget_set_usize(dialog, 400, 150);
+ gtk_widget_set_usize(dialog, 500, 150);
  gtk_window_set_modal(GTK_WINDOW(dialog), 1);
  label = gtk_label_new(msg);
  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), label, TRUE, TRUE, 0);
@@ -243,12 +257,13 @@ void gtk_dialog_printf_with_title(const char* title, const char* fmt, ...)
  gtk_main();
 }
 
+
 void gtk_dialog_mbox(const char* title, const char* msg)
 {
  GtkWidget* dialog, *label, *button;
  dialog = gtk_dialog_new();
  gtk_window_set_title(GTK_WINDOW(dialog), title);
- gtk_widget_set_usize(dialog, 400, 150);
+ gtk_widget_set_usize(dialog, 500, 150);
  gtk_window_set_modal(GTK_WINDOW(dialog), 1);
  label = gtk_label_new(msg);
  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), label, TRUE, TRUE, 0);
@@ -263,6 +278,7 @@ void gtk_dialog_mbox(const char* title, const char* msg)
  gtk_main();
 }
 
+
 int gtk_dialog_yes_no_printf(const char* fmt, ...)
 {
  GtkWidget* dialog, *label, *button_yes, *button_no;
@@ -273,7 +289,7 @@ int gtk_dialog_yes_no_printf(const char* fmt, ...)
  va_end(ap);
  dialog = gtk_dialog_new();
  gtk_window_set_title(GTK_WINDOW(dialog), "Confirmation needed.");
- gtk_widget_set_usize(dialog, 400, 150);
+ gtk_widget_set_usize(dialog, 500, 150);
  gtk_window_set_modal(GTK_WINDOW(dialog), 1);
  label = gtk_label_new(question);
  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), label, TRUE, TRUE, 0);
@@ -293,12 +309,13 @@ int gtk_dialog_yes_no_printf(const char* fmt, ...)
  return (answer==ANSWER_YES)?1:0;
 }
 
+
 int gtk_dialog_with_2_buttons(const char* question, char* but1, char* but2)
 {
  GtkWidget* dialog, *label, *button_yes, *button_no;
  dialog = gtk_dialog_new();
  gtk_window_set_title(GTK_WINDOW(dialog), "Confirmation needed.");
- gtk_widget_set_usize(dialog, 400, 150);
+ gtk_widget_set_usize(dialog, 500, 150);
  gtk_window_set_modal(GTK_WINDOW(dialog), 1);
  label = gtk_label_new(question);
  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), label, TRUE, TRUE, 0);
@@ -318,12 +335,13 @@ int gtk_dialog_with_2_buttons(const char* question, char* but1, char* but2)
  return (answer==ANSWER_YES)?1:0;
 }
 
+
 int gtk_dialog_yes_no(const char* question)
 {
  GtkWidget* dialog, *label, *button_yes, *button_no;
  dialog = gtk_dialog_new();
  gtk_window_set_title(GTK_WINDOW(dialog), "Confirmation needed.");
- gtk_widget_set_usize(dialog, 400, 150);
+ gtk_widget_set_usize(dialog, 500, 150);
  gtk_window_set_modal(GTK_WINDOW(dialog), 1);
  label = gtk_label_new(question);
  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), label, TRUE, TRUE, 0);
@@ -343,6 +361,7 @@ int gtk_dialog_yes_no(const char* question)
  return (answer==ANSWER_YES)?1:0;
 }
 
+
 int setup_combo(PGconn* c, GtkWidget* w, GtkWidget** cmb)
 {
  char errstr[MAX_QUERY_LENGTH];
@@ -354,7 +373,7 @@ int setup_combo(PGconn* c, GtkWidget* w, GtkWidget** cmb)
  {
   gtk_dialog_printf("%s", errstr);
   cmb=NULL;
-  return -1; 
+  return -1;
  }
 /* list = g_list_append(list," Select DB");*/
  for (i=0;i<row;i++) list = g_list_append(list, ptr[i][0]);
@@ -366,6 +385,7 @@ int setup_combo(PGconn* c, GtkWidget* w, GtkWidget** cmb)
  return 0;
 }
 
+
 char* gtk_dialog_getdbs(PGconn* connection, char* fmt, ...)
 {
  GtkWidget* dialog, *combo, *button, *label;
@@ -377,7 +397,7 @@ char* gtk_dialog_getdbs(PGconn* connection, char* fmt, ...)
  strcpy(tentry,"");
  dialog = gtk_dialog_new();
  gtk_window_set_title(GTK_WINDOW(dialog),msg);
- gtk_widget_set_usize(dialog, 400, 80);
+ gtk_widget_set_usize(dialog, 500, 80);
  gtk_window_set_modal(GTK_WINDOW(dialog), 1);
  label = gtk_label_new("Select One:");
  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), label, TRUE, TRUE, 0);
