@@ -10,31 +10,31 @@
  ! BUT I DON'T KNOW THEIR PERSONALITY SO SORRY !
  ! I CANNOT ADD THEM TO AUTORS, BUT THANKS FOR SUPPORT ME !
  FILE: main.c */
-#include "gtkincl.h"
-#include "consoleout.h"
-#include "gtkdialogs.h"
+
+#include "main.h"
 #include "pgxexplorer.h"
 
 void disconnect()
 {
- disconnect_db(&connection);
+ if (connected) disconnect_db(&connection);
+ connected=0;
+ connection=0;
 }
 
-
-static void __dummy( GtkWidget *w,gpointer   data )
+void __dummy( GtkWidget *w,gpointer   data )
 {
   error("Not yet implemented.\n");
 }
 
 
-static void close_results( GtkWidget *w,gpointer   data)
+void close_results( GtkWidget *w,gpointer   data)
 {
  gtk_main_quit();
  gtk_widget_destroy((GtkWidget*)(data));
 }
 
 
-static void qexec_quit( GtkWidget *w,gpointer   data)
+void qexec_quit( GtkWidget *w,gpointer   data)
 {
  gtk_main_quit();
  gtk_widget_destroy(query_exec);
@@ -42,11 +42,13 @@ static void qexec_quit( GtkWidget *w,gpointer   data)
 }
 
 
-static int menu_quit( GtkWidget *w,gpointer   data)
+int menu_quit(GtkWidget *w, gpointer data)
 {
   if (gtk_dialog_yes_no("Are you sure?"))
    {
     disconnect();
+    if (currentbase) free(currentbase);
+    currentbase=NULL;
     gtk_main_quit();
     if (query_exec)
        {
@@ -59,21 +61,19 @@ static int menu_quit( GtkWidget *w,gpointer   data)
 }
 
 
-static void about_box( GtkWidget *w,gpointer   data)
+void about_box( GtkWidget *w,gpointer   data)
 {
- gtk_dialog_printf("PgXexplorer: version 0.1 alpha", "Written by\nMorgoth DBMA\nPgXexplorer\nCurrently connected to: %s", currentbase);
+ about_window_new();
 }
 
-void fatal_nodb(char*, char*,int);
-	
-static void create_DB_from_file(GtkWidget* w, gpointer data)
+void create_DB_from_file(GtkWidget* w, gpointer data)
 {
  char *filen,*sfilen,*dbn;
  char errstr[MAX_QUERY_LENGTH];
  char dbname[MAXPATH];
  FILE* f;
  char*** ptr;
- int l,row,col;
+ int l,row,col,emerg;
  char winname[STDSTRING];
  dbn = gtk_dialog_gettext_printf("Need DB name to fill from a SQL file:");
  if (!strcmp(dbn,""))
@@ -92,7 +92,7 @@ static void create_DB_from_file(GtkWidget* w, gpointer data)
  sfilen = malloc(l+1);
  strcpy(sfilen,filen);
  downcase(sfilen);
- if (l<5 || sfilen[l-1]!='l' || sfilen[l-2]!='q' || sfilen[l-3] !='s' || sfilen[l-4]!='.') 
+ if (l<5 || sfilen[l-1]!='l' || sfilen[l-2]!='q' || sfilen[l-3] !='s' || sfilen[l-4]!='.')
       {
        gtk_dialog_printf("This is not a .SQL file.\n");
        free(sfilen);
@@ -106,7 +106,14 @@ static void create_DB_from_file(GtkWidget* w, gpointer data)
     return ;
    }
  fclose(f);
+ emerg = !connected;
+ if (!connected && !dummy_connect(1,TEMPLATE)) 
+   {
+    gtk_dialog_printf("Cannot connect to template DB\nResult: Cannot create new DB");
+    return ;
+   }
  execute_printf(connection, &ptr, &row, &col, errstr, "CREATE DATABASE %s", dbname);
+ if (emerg) { dummy_connect(0,TEMPLATE); connected = 0; }
  if (row<0 || col<0)
    {
     gtk_dialog_printf_big("Error executing query:\nReturn from DBMS: %s\n", errstr);
@@ -114,22 +121,27 @@ static void create_DB_from_file(GtkWidget* w, gpointer data)
    }
  free_p3c(&ptr, row, col);
  system_printf("psql %s -f %s", dbname, filen);
- l = gtk_dialog_yes_no_printf("Switch from database\n%s to %s now?", currentbase, dbname);
+ if (!connected) l = 1;
+ else l = gtk_dialog_yes_no_printf("Switch from database\n%s to %s now?", currentbase, dbname);
  if (l)
   {
-   disconnect();
-   free(currentbase);
-   sprintf(winname, "PgXexplorer: (no database opened currently)");
-   gtk_window_set_title (GTK_WINDOW(main_wnd), winname);
+   if (!emerg)
+     {
+      disconnect();
+      if (currentbase) free(currentbase);
+      currentbase=NULL;
+      sprintf(winname, "PgXexplorer: (no database opened currently)");
+      gtk_window_set_title (GTK_WINDOW(main_wnd), winname);
+     }
    connection = gtk_connect_db(dbname, errstr);
    if (!connection)
      {
-      fatal_nodb(dbname,errstr,1);
-      exit(1);
+      fatal_nodb(dbname,errstr,0);
       return ;
      }
    else
      {
+      connected=1;
       currentbase = (char*)malloc(strlen(dbname)+2);
       strcpy(currentbase, dbname);
       sprintf(winname, "PgXexplorer: %s", currentbase);
@@ -138,12 +150,16 @@ static void create_DB_from_file(GtkWidget* w, gpointer data)
   }
 }
 
-static void save_database(GtkWidget* w, gpointer data)
+
+void save_database(GtkWidget* w, gpointer data)
 {
  int a;
  char* filename;
  char* dbname;
  char dbs[STDSTRING];
+ int emerg;
+ if (!connected) a=0;
+ else 
  a = gtk_dialog_with_2_buttons("Do You want to save Current database or Other database?", "Current", "Other");
  if (a)
    {
@@ -158,7 +174,14 @@ static void save_database(GtkWidget* w, gpointer data)
    }
  else
  {
+  emerg = !connected;
+  if (!connected && !dummy_connect(1,TEMPLATE))
+    {
+     gtk_dialog_printf("Cannot connect to template DB\nCannot get DB list.");
+     return ;
+    }
   dbname = gtk_dialog_getdbs(connection, "Which DB save?");
+  if (emerg) { dummy_connect(0,TEMPLATE); connected=0; }
   strcpy(dbs, dbname);  /* HEADERS WILL USE OLD POINTER IN DIALOGS, SO MUST COPY IT */
   			/* NOW VARIABLE dbs IS A COPY, AND dbname CAN (NOT MUST) */
   			/* BE CHANGED BY DIALOGS */
@@ -183,9 +206,14 @@ char *dbenv()
 
 void fatal_nodb(char* dbname, char* errstr, int killed)
 {
+ if (killed)
  gtk_dialog_printf_big_with_title("PgXexplorer Fatal Error",
  	"Cannot connect to DB: %s\nDBMS returned: \n%s\nSystem will now exit.\nENV=\n%s",
   	dbname,errstr,dbenv());
+ else 
+ gtk_dialog_printf_big_with_title("PgXexplorer Error",
+ 	"Cannot connect to DB: %s\nDBMS returned: \n%s\nENV=\n%s",
+  	dbname,errstr,dbenv());
  if(killed) exit(1);
 }
 
@@ -202,7 +230,8 @@ void reload_bases(char* db, int ask)
  /**/
  if (!a) return;
  disconnect();
- free(currentbase);
+ if (currentbase) free(currentbase);
+ currentbase=NULL;
  while (!strcmp(dbname,""))
    {
     gtk_dialog_printf("Cannot switch to an empty DB");
@@ -213,11 +242,12 @@ void reload_bases(char* db, int ask)
  connection = gtk_connect_db(dbname, errstr);
  if (!connection)
    {
-    fatal_nodb(dbname,errstr,1);
+    fatal_nodb(dbname,errstr,0);
     return ;
    }
  else
    {
+    connected=1;
     currentbase = (char*)malloc(strlen(dbname)+2);
     strcpy(currentbase, dbname);
     sprintf(winname, "PgXexplorer: %s", currentbase);
@@ -225,35 +255,48 @@ void reload_bases(char* db, int ask)
    }
 }
 
-static void load_database(GtkWidget* w, gpointer data)
+
+void load_database(GtkWidget* w, gpointer data)
 {
  char* dbname;
  char winname[STDSTRING];
  char errstr[MAX_QUERY_LENGTH];
+ int emerg;
+ emerg = !connected;
+ if (!connected && !dummy_connect(1,TEMPLATE)) 
+   {
+    gtk_dialog_printf("Cannot connect to template DB\nServer is dead?");
+    return;
+   }
  dbname = gtk_dialog_getdbs(connection, "Which DB load?");
+ if (emerg) { dummy_connect(0,TEMPLATE); connected = 0; }
  if (!strcmp(dbname,""))
     {
      gtk_dialog_printf("Will not load empty DB name");
      return;
     }
- if (!strcmp(dbname,currentbase))
+ if (!emerg && connected && !strcmp(dbname,currentbase))
     {
      gtk_dialog_printf("This DB: %s, You are currently using", currentbase);
      return ;
     }
- disconnect();
- free(currentbase);
- sprintf(winname, "PgXexplorer: (no database opened currently)");
- gtk_window_set_title (GTK_WINDOW(main_wnd), winname);
+ if (!emerg)
+   {
+    disconnect();
+    if (currentbase) free(currentbase);
+    currentbase=NULL;
+    sprintf(winname, "PgXexplorer: (no database opened currently)");
+    gtk_window_set_title (GTK_WINDOW(main_wnd), winname);
+   }
  connection = gtk_connect_db(dbname, errstr);
  if (!connection)
      {
-      fatal_nodb(dbname,errstr,1);
-      exit(1);
+      fatal_nodb(dbname,errstr,0);
       return ;
      }
    else
      {
+      connected=1;
       currentbase = (char*)malloc(strlen(dbname)+2);
       strcpy(currentbase, dbname);
       sprintf(winname, "PgXexplorer: %s", currentbase);
@@ -261,27 +304,46 @@ static void load_database(GtkWidget* w, gpointer data)
      }
 }
 
-static void drop_database(GtkWidget* w, gpointer data)
+
+void drop_database(GtkWidget* w, gpointer data)
 {
  char* dbname;
  char errstr[MAX_QUERY_LENGTH];
  PGresult *result;
+ int emerg;
+ emerg = !connection;
+ if (!connected && !dummy_connect(1,TEMPLATE))
+   {
+     gtk_dialog_printf("Cannot connect to template DB\nCannot get DB list");
+     return;
+   }
  dbname = gtk_dialog_getdbs(connection, "Which DB drop?");
  if (!strcmp(dbname,""))
     {
      gtk_dialog_printf("Will not drop empty DB name\nTry once again.");
+     if (emerg) { dummy_connect(0,TEMPLATE); connected = 0; }
      return;
     }
- if (!strcmp(dbname,currentbase))
+ if (!emerg && connected && !strcmp(dbname,currentbase))
     {
      gtk_dialog_printf("Cannot drop DB: %s, currently used!", currentbase);
      return ;
     }
  if (strstr(dbname, "template"))
    {
-    if (!gtk_dialog_yes_no_printf("Are You sure want to drop\ntemplate DB: %s",dbname)) return ;
+    if (emerg) 
+      { 
+       dummy_connect(0,TEMPLATE); 
+       connected = 0; 
+       gtk_dialog_printf("Cannot drop template\nwhile it is beeing used\nas emergency DB!");
+       return ;
+      }
+    if (!gtk_dialog_yes_no_printf(
+    "Are You sure want to drop\ntemplate DB: %s\nThis can prevent PgXexplorer working properly",dbname)) 
+	    return ;
    }
  execute_printf_query(connection, &result, errstr, "DROP DATABASE %s", dbname);
+ if (emerg) { dummy_connect(0,TEMPLATE); connected = 0; }
  if (!result)
    {
     gtk_dialog_printf_big("Error executing query:\nReturn from DBMS: %s\n", errstr);
@@ -289,13 +351,16 @@ static void drop_database(GtkWidget* w, gpointer data)
    }
 }
 
-static void create_database(GtkWidget* w, gpointer data)
+
+void create_database(GtkWidget* w, gpointer data)
 {
  char* dbname;
  char errstr[MAX_QUERY_LENGTH];
  char winname[STDSTRING];
  int a;
+ int emerg;
  PGresult *result;
+ emerg=!connected;
  dbname = gtk_dialog_gettext("Enter database name: ");
  if (!strcmp(dbname,""))
     {
@@ -303,28 +368,39 @@ static void create_database(GtkWidget* w, gpointer data)
      return;
     }
  result = NULL;
+ if (!connected && !dummy_connect(1,TEMPLATE)) 
+   {
+    gtk_dialog_printf("Cannot connect to template DB\nResult: Cannot create new DB");
+    return ;
+   }
  execute_printf_query(connection, &result, errstr, "CREATE DATABASE %s", dbname);
+ if (emerg) { dummy_connect(0,TEMPLATE); connected = 0; }
  if (!result)
    {
     gtk_dialog_printf_big("Error executing query:\nReturn from DBMS: %s\n", errstr);
     return;
    }
- a = gtk_dialog_yes_no_printf("Switch from database\n%s to %s now?", currentbase, dbname);
+ if (!connected) a = 1;
+ else a = gtk_dialog_yes_no_printf("Switch from database\n%s to %s now?", currentbase, dbname);
  if (a)
   {
-   disconnect();
-   free(currentbase);
-   sprintf(winname, "PgXexplorer: (no database opened currently)");
-   gtk_window_set_title (GTK_WINDOW(main_wnd), winname);
+   if (!emerg)
+     {
+      disconnect();
+      if (currentbase) free(currentbase);
+      currentbase=NULL;
+      sprintf(winname, "PgXexplorer: (no database opened currently)");
+      gtk_window_set_title (GTK_WINDOW(main_wnd), winname);
+     }
    connection = gtk_connect_db(dbname, errstr);
    if (!connection)
      {
-      fatal_nodb(dbname,errstr,1);
-      exit(1);
+      fatal_nodb(dbname,errstr,0);
       return ;
      }
    else
      {
+      connected=1;
       currentbase = (char*)malloc(strlen(dbname)+2);
       strcpy(currentbase, dbname);
       sprintf(winname, "PgXexplorer: %s", currentbase);
@@ -334,7 +410,7 @@ static void create_database(GtkWidget* w, gpointer data)
 }
 
 
-static void exec_test_prog(GtkWidget* w, gpointer data)
+void exec_test_prog(GtkWidget* w, gpointer data)
 {
  system("./pgxtest");
 }
@@ -388,6 +464,7 @@ void gtk_table_out(char* title, char*** str_data, int a, int b)
 }
 
 /*                    TEST QUERY EXEC FUNC
+
 void test_queries()
 {
  char*** ptr;
@@ -397,10 +474,11 @@ void test_queries()
  if (a<0 || b<0)
  {
   gtk_dialog_printf("%s", errstr);
-  return ; 
+  return ;
  }
  free_p3c(&ptr,a,b);
 }
+
 */
 
 void clear_txt_ctrl(GtkWidget* w)
@@ -410,12 +488,18 @@ void clear_txt_ctrl(GtkWidget* w)
  gtk_text_forward_delete(GTK_TEXT(w), l);
 }
 
-static void load_proc(GtkWidget* w, gpointer txt)
+
+void load_proc(GtkWidget* w, gpointer txt)
 {
  char* filen;
  FILE* f;
  int l;
  char* str;
+ if (!connected)
+   {
+    gtk_dialog_printf("Connect to DB firest!");
+    return;
+   }
  filen = gtk_dialog_getfile("Select query file (*.QUE)");
  if (!strcmp(filen,""))
    {
@@ -441,7 +525,8 @@ static void load_proc(GtkWidget* w, gpointer txt)
  free(str);
 }
 
-static void save_proc(GtkWidget* w, gpointer txt)
+
+void save_proc(GtkWidget* w, gpointer txt)
 {
  char *t,*filen;
  char filename[MAXPATH];
@@ -469,13 +554,13 @@ static void save_proc(GtkWidget* w, gpointer txt)
  if (f)
    {
     fclose(f);
-    if (!gtk_dialog_yes_no_printf("Overwite file: %s?", filename)) 
+    if (!gtk_dialog_yes_no_printf("Overwite file: %s?", filename))
       {
        free(t);
        return ;
       }
    }
- f = fopen(filename,"w"); 
+ f = fopen(filename,"w");
  if (!f)
    {
     gtk_dialog_printf("Cannot write to: %s\n", filename);
@@ -488,13 +573,19 @@ static void save_proc(GtkWidget* w, gpointer txt)
  gtk_dialog_printf("Saved to %s\n", filename);
 }
 
-static void execute_proc(GtkWidget* w, gpointer txt)
+
+void execute_proc(GtkWidget* w, gpointer txt)
 {
  char* t;
  int l,i,a,b;
  PGresult *result;
  char errstr[MAX_QUERY_LENGTH];
  char*** out;
+ if (!connected)
+   {
+    gtk_dialog_printf("Connect to DB first!");
+    return;
+   }
  l = gtk_text_get_length(GTK_TEXT(txt));
  if (l<3)
     {
@@ -567,7 +658,7 @@ char* get_env(char* str)
 }
 
 
-static void env_dialog(GtkWidget* www, gpointer d)
+void env_dialog(GtkWidget* www, gpointer d)
 {
  GtkWidget* dialog, *label[4], *button[3], *entry[4], *table;
  char **t_entry;
@@ -635,17 +726,27 @@ static void env_dialog(GtkWidget* www, gpointer d)
 }
 
 
-static void check_exec_proc(GtkWidget* txt, gpointer dlg)
+void check_exec_proc(GtkWidget* txt, gpointer dlg)
 {
  int l;
  l = gtk_text_get_length(GTK_TEXT(txt));
- if (GTK_TEXT_INDEX(GTK_TEXT(txt), l-1)==';') execute_proc(dlg,(GtkWidget*)txt);
+ if (GTK_TEXT_INDEX(GTK_TEXT(txt), l-1)==';') 
+ {
+  gtk_text_set_point(GTK_TEXT(txt), l);
+  gtk_text_backward_delete(GTK_TEXT(txt), 1);
+  execute_proc(dlg,(GtkWidget*)txt);
+ }
 }
 
 
-static void query_executor(GtkWidget* w, gpointer data)
+void query_executor(GtkWidget* w, gpointer data)
 {
  GtkWidget* window, *table, *text, *hscrollbar, *vscrollbar, *button[3];
+ if (!connected)
+   {
+    gtk_dialog_printf("Connect to DB first!");
+    return;
+   }
  if (query_exec)
    {
     gtk_dialog_printf("Another instance of QueryExecutor is running.");
@@ -744,8 +845,9 @@ void get_main_menu( GtkWidget  *window,GtkWidget **menubar )
   gtk_item_factory_create_items (item_factory, nmenu_items, menu_items, NULL);
   gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
   if (menubar) *menubar = gtk_item_factory_get_widget (item_factory, "<main>");
-  error("menu is not yet implemented.\n");
 }
+
+
 int dummy_connect(int cn, char* templ)
 {
  char errstr[MAX_ENTRY_LENGTH];
@@ -757,12 +859,44 @@ int dummy_connect(int cn, char* templ)
       gtk_dialog_printf("Connect to template DB: %s failed\nDBMS returned:\n%s", templ,errstr);
       return 0;
      }
+   connected=1;
    return 1;
   }
  disconnect();
  return 0;
 }
 
+
+void todo()
+{
+ printf("przejrzec dokladnie przyklady w gtkex/\n");
+ printf("see entire DB, zakladki (notepads)i w kazdej tablica, nazwy kolumn\n");
+ printf("nazwy kolumn w wyniku zapytania SQL, jezeli #rows>0\n");
+ printf("dodac to do klasy funkcji: execute_(...)\n");
+ printf("toolbar ze skrotami, oddzielny plik: toolbar.[ch]\n");
+ printf("header dla funkcji toolbara: main.h (naglowki funkcji z main menu)\n");
+ printf("tablice in tree-view, typy danych w combo\n");
+ printf("dla tabeli: tablica: nazwa kolumny, typ (combo)\n");
+ printf("operacje na tablicach itp. w menu kontekstowym\n");
+ printf("jakis obrazek w about_box, niech uzyje mjpeg.c, mjpeg.h\n");
+ printf("aby uzyc mjpeg, trzeba gtk_window_get_xwindow, i gdk events\n");
+ printf("trigery: w menu kontekstowym, i add/delete table etc.\n");
+ printf("kreator tworzenia tablicy, zapytania (Create Query? do menu)\n");
+ printf("Potem zapisanie kwerendy i wykonanie jej (w kreatorze\n");
+ printf("zapytania musi byc opcja wczytania z pliku juz gotowego)\n");
+ printf("dodawanie tabeli, usuwanie tabeli (modyf. w combo i alter_tab)\n");
+ printf("dodawanie danych do tablicy, jako caly wiersz i <Add>\n");
+ printf("kasowanie calych wierszy w tablicy\n");
+ printf("modyfikacja wierszy w tablicy <SIC!>\n");
+ printf("synchronizacja, jak wykonanie kwerendy w Qexec to update ctrls\n");
+ printf("kreator tworzenia triggera, zapis do pliku, wczytanie trg\n");
+ printf("WIDOKU RELACYJNEGO NAJPRAWDOPODOBNIEJ NIE BEDZIE\n");
+ printf("CHYBA ZE SIE DOWIEM JAK OKRESLIC CZY DANA JEST KUCZEM pk LUB fk\n");
+ printf("! kreator tworzenia triggera w C, kompilowanie do *.so\n");
+ printf("kreator tworzenia widoku, zapis kodu SQL widoku i odczyt\n");
+}
+
+
 int parse_cmdline(int lb, char** par, GtkWidget* w)
 {
  char* dbname;
@@ -787,15 +921,17 @@ int parse_cmdline(int lb, char** par, GtkWidget* w)
 				 "-p port\n"
 				 "-b base dir"
 				 ); return 1;
-       default: gtk_dialog_printf("Unrecognized command line option\noptions are:\n-d data_base_name\n-h help"); return 1;
+       default: 
+		gtk_dialog_printf("Unrecognized command line option\noptions are:\n-d data_base_name\n"
+				   "-h help"); return 1;
       }
    }
- if (!gotdb) 
-    { 
-     if (dummy_connect(1,"template1")) 
+ if (!gotdb)
+    {
+     if (dummy_connect(1,TEMPLATE))
        {
-	dbname = gtk_dialog_getdbs(connection, "Connect to database: "); 
-        dummy_connect(0,"template1");
+	dbname = gtk_dialog_getdbs(connection, "Connect to database: ");
+        dummy_connect(0,TEMPLATE);
        }
      else dbname = gtk_dialog_gettext("Type DB name manually:");
     }
@@ -813,6 +949,7 @@ int parse_cmdline(int lb, char** par, GtkWidget* w)
    }
  else
    {
+    connected=1;
     currentbase = (char*)malloc(strlen(dbname)+2);
     strcpy(currentbase, dbname);
     if (gotdb) free(dbname);
@@ -826,8 +963,10 @@ int main(int lb, char **par)
   GtkWidget *window;
   GtkWidget *main_vbox;
   GtkWidget *menubar;
+  GtkWidget* toolbar;
   char winname[MAX_ENTRY_LENGTH];
   int err;
+  todo();
   gtk_init (&lb, &par);
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   /*gtk_signal_connect (GTK_OBJECT (window), "destroy", GTK_SIGNAL_FUNC (gtk_main_quit), "WM destroy");*/
@@ -838,10 +977,14 @@ int main(int lb, char **par)
   gtk_container_add (GTK_CONTAINER (window), main_vbox);
   gtk_widget_show (main_vbox);
   get_main_menu (window, &menubar);
+  get_toolbar(window, &toolbar);
   gtk_box_pack_start (GTK_BOX (main_vbox), menubar, FALSE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (main_vbox), toolbar, FALSE, TRUE, 0);
+  gtk_widget_show (toolbar);
   gtk_widget_show (menubar);
   gtk_widget_show (window);
   main_wnd = window;
+  setup_signals();
   err = parse_cmdline(lb,par,window);
   if (err) return 1;
   else
@@ -849,7 +992,7 @@ int main(int lb, char **par)
      sprintf(winname, "PgXexplorer: %s", currentbase);
      gtk_window_set_title (GTK_WINDOW(window), winname);
     }
-  gtk_main ();
+  gtk_main();
   return(0);
 }
 
