@@ -6,12 +6,12 @@
  written in VIM editor, ctags used, CVS used
  Currently only one author: MOrgoth DBMA
  FILE: pgxexplorer.h */
-
 #define STDSTRING 100
 #define MAXPATH 1024
+#define TEMPLATE "template1"
 PGconn* connection;	/* variables here */
 char* currentbase;
 char tmpstr[1024];
 GtkWidget* main_wnd;
 GtkWidget* query_exec;
-
+int connected=0;
