@@ -9,8 +9,7 @@
 #include <libpq-fe.h>
 #include "consoleout.h"
 #include "query.h"
-
-
+#include "signals.h"
 /*FIXME dodac obsluge debug, error ==> DlgWindow*/
 
 PGconn* connect_db(char* arg)
@@ -21,7 +20,9 @@ PGconn* connect_db(char* arg)
  strarg = (char*)malloc(strlen(arg)+16);
  debug("\nconnect to database %s\n", arg);
  sprintf(strarg,"dbname=%s", arg);
+ alarm_clock(10);
  conn = PQconnectdb(strarg);
+ alarm_stop();
  if (PQstatus(conn) == CONNECTION_BAD)
    {
     error("\nCannot connect to DB:%s\n", arg);
@@ -32,6 +33,7 @@ PGconn* connect_db(char* arg)
  return conn;
 }
 
+
 PGconn* gtk_connect_db(char* arg, char* errstr)
 {
  PGconn* conn;
@@ -39,8 +41,10 @@ PGconn* gtk_connect_db(char* arg, char* errstr)
  conn=0;
  strarg = (char*)malloc(strlen(arg)+16);
  sprintf(strarg,"dbname=%s", arg);
+ alarm_clock(10);
  conn = PQconnectdb(strarg);
- if (PQstatus(conn) == CONNECTION_BAD) 
+ alarm_stop();
+ if (PQstatus(conn) == CONNECTION_BAD)
   {
    sprintf(errstr, "Connection string:\ndbname=%s failed.", arg);
    free(strarg);
@@ -50,6 +54,7 @@ PGconn* gtk_connect_db(char* arg, char* errstr)
  return conn;
 }
 
+
 void clear_result(PGresult** r)
 {
  if (*r) PQclear(*r);
@@ -61,7 +66,8 @@ void clear_result(PGresult** r)
 void disconnect_db(PGconn** c)
 {
  debug("disconnect DB\n");
- PQfinish(*c);
+ if (*c) PQfinish(*c);
+ *c = NULL;
 }
 
 
@@ -75,6 +81,7 @@ PGresult* execute_silent_query(PGconn* c,  char* query)
     debug("NULL query passed\n");
     return NULL;
    }
+ if (!c) return NULL;
  r= PQexec(c, query);
  if (!r)
    {
@@ -91,6 +98,7 @@ PGresult* execute_silent_query(PGconn* c,  char* query)
  return r;
 }
 
+
 char*** p3c_execute_printf(PGconn* c,int* row, int* col, char* errstr, char* fmt,...)
 {
  va_list ap;
@@ -103,6 +111,7 @@ char*** p3c_execute_printf(PGconn* c,int* row, int* col, char* errstr, char* fmt
  return ret;
 }
 
+
 void execute_printf(PGconn* c, char**** res, int* row, int* col, char* errstr, char* fmt,...)
 {
  int stat;
@@ -113,6 +122,13 @@ void execute_printf(PGconn* c, char**** res, int* row, int* col, char* errstr, c
  vsprintf(query,fmt,ap);
  va_end(ap);
  r=NULL;
+ if (!c)
+   {
+    *res = NULL;
+    *row = *col = -1;
+    strcpy(errstr, "Not connected to DB");
+    return;
+   }
  if (!query)
    {
     *res = NULL;
@@ -141,6 +157,7 @@ void execute_printf(PGconn* c, char**** res, int* row, int* col, char* errstr, c
  clear_result(&r);
 }
 
+
 void execute_printf_query(PGconn* c,PGresult** r, char* errstr, char* fmt,...)
 {
  int stat;
@@ -149,6 +166,12 @@ void execute_printf_query(PGconn* c,PGresult** r, char* errstr, char* fmt,...)
  va_start(ap, fmt);
  vsprintf(query,fmt,ap);
  va_end(ap);
+ if (!c)
+   {
+    *r = NULL;
+    strcpy(errstr, "Not connected to DB");
+    return;
+   }
  if (!query)
    {
     *r = NULL;
@@ -182,6 +205,7 @@ PGresult* execute_query(PGconn* c,  char* query)
     ERR error("NULL query passed\n");
     return NULL;
    }
+ if (!c) return NULL;
  r= PQexec(c, query);
  if (!r)
    {
