@@ -20,6 +20,8 @@ void disconnect_db(PGconn**);
 PGresult* execute_silent_query(PGconn*,char*);
 PGresult* execute_query(PGconn*,char*);
 void execute_printf_query(PGconn*,PGresult**,char*, char*,...);
+void execute_printf(PGconn*,char****, int*, int*, char*, char*,...);
+char*** p3c_execute_printf(PGconn*,int*, int*,char*,char*,...);
 char*** pgres2pc3(const PGresult*,int*,int*);
 void free_p3c(char****,int,int);
 #endif
